@@ -68,10 +68,11 @@ AndroidMediaLibrary::start()
 }
 
 bool
-AndroidMediaLibrary::addDevice(const std::string& uuid, const std::string& path, bool removable)
+AndroidMediaLibrary::addDevice(const std::string& uuid, const std::string& path, bool removable, bool notify)
 {
     p_lister->addDevice(uuid, path, removable);
-    return p_DeviceListerCb != nullptr && p_DeviceListerCb->onDevicePlugged(uuid, path);
+    return p_DeviceListerCb != nullptr && notify ? p_DeviceListerCb->onDevicePlugged(uuid, path)
+                                                 : !p_DeviceListerCb->isDeviceKnown(uuid);
 }
 
 std::vector<std::tuple<std::string, std::string, bool>>
@@ -113,12 +114,6 @@ AndroidMediaLibrary::entryPoints()
     return p_ml->entryPoints();
 }
 
-bool
-AndroidMediaLibrary::isWorking()
-{
-    return !m_paused && (m_nbDiscovery > 0 || (m_progress > 0 && m_progress < 100));
-}
-
 void
 AndroidMediaLibrary::pauseBackgroundOperations()
 {
@@ -759,6 +754,21 @@ void AndroidMediaLibrary::onParsingStatsUpdated( uint32_t percent)
     }
 }
 
+
+void AndroidMediaLibrary::onBackgroundTasksIdleChanged( bool isIdle )
+{
+    JNIEnv *env = getEnv();
+    if (env == NULL)
+        return;
+    jobject thiz = getWeakReference(env);
+    if (thiz != NULL)
+    {
+        env->CallVoidMethod(thiz, p_fields->MediaLibrary.onBackgroundTasksIdleChangedId, isIdle);
+        if (weak_compat)
+            env->DeleteLocalRef(thiz);
+    }
+}
+
 jobject
 AndroidMediaLibrary::getWeakReference(JNIEnv *env)
 {
