@@ -1203,7 +1203,19 @@ public class PlaybackService extends MediaBrowserServiceCompat implements IVLCVo
         }
 
         @Override
-        public void onPlayFromSearch(String query, Bundle extras) {
+        public void onPlayFromSearch(final String query, final Bundle extras) {
+            if (!mMedialibrary.isInitiated()) {
+                startService(new Intent(MediaParsingService.ACTION_INIT, null, PlaybackService.this, MediaParsingService.class));
+                final BroadcastReceiver libraryReadyReceiver = new BroadcastReceiver() {
+                    @Override
+                    public void onReceive(Context context, Intent intent) {
+                        LocalBroadcastManager.getInstance(PlaybackService.this).unregisterReceiver(this);
+                        onPlayFromSearch(query, extras);
+                    }
+                };
+                LocalBroadcastManager.getInstance(PlaybackService.this).registerReceiver(libraryReadyReceiver, new IntentFilter(VLCApplication.ACTION_MEDIALIBRARY_READY));
+                return;
+            }
             mMediaSession.setPlaybackState(new PlaybackStateCompat.Builder().setState(PlaybackStateCompat.STATE_CONNECTING, getTime(), 1.0f).build());
             VoiceSearchParams vsp = new VoiceSearchParams(query, extras);
             MediaLibraryItem[] items = null;
@@ -1502,12 +1514,9 @@ public class PlaybackService extends MediaBrowserServiceCompat implements IVLCVo
         mShuffling = mSettings.getBoolean(audio ? "audio_shuffling" : "media_shuffling", false);
         mRepeating = mSettings.getInt(audio ? "audio_repeating" : "media_repeating", REPEAT_NONE);
         int position = mSettings.getInt(audio ? "position_in_audio_list" : "position_in_media_list", 0);
-        long time = mSettings.getLong(audio ? "position_in_song" : "position_in_media", -1);
-        mSavedTime = time;
+        mSavedTime = mSettings.getLong(audio ? "position_in_song" : "position_in_media", -1);
         // load playlist
         load(playList, position);
-        if (time > 0)
-            seek(time);
         if (!audio) {
             boolean paused = mSettings.getBoolean(PreferencesActivity.VIDEO_PAUSED, !isPlaying());
             float rate = mSettings.getFloat(PreferencesActivity.VIDEO_SPEED, getRate());
