@@ -34,7 +34,6 @@ import android.content.res.TypedArray;
 import android.graphics.Color;
 import android.os.Build;
 import android.os.Bundle;
-import android.os.Parcelable;
 import android.support.v4.app.DialogFragment;
 import android.support.v4.content.ContextCompat;
 import android.support.v7.preference.PreferenceManager;
@@ -229,12 +228,9 @@ public class AdvOptionsDialog extends DialogFragment implements View.OnClickList
                 tag = "select_chapter";
                 break;
             case ID_SAVE_PLAYLIST:
-                newFragment = new SavePlaylistDialog();
-                Bundle args = new Bundle();
-                args.putParcelableArray(SavePlaylistDialog.KEY_TRACKS, (Parcelable[]) mService.getMedias().toArray());
-                newFragment.setArguments(args);
-                tag = "fragment_save_playlist";
-                break;
+                UiTools.addToPlaylist(getActivity(), mService.getMedias());
+                dismiss();
+                return;
             default:
                 return;
         }
