@@ -52,6 +52,7 @@ public abstract class BaseTvActivity extends PlaybackServiceActivity {
     protected Medialibrary mMediaLibrary;
     protected SharedPreferences mSettings;
     boolean mRegistering = false;
+    private volatile boolean mIsVisible = false;
 
     @Override
     protected void onCreate(Bundle savedInstanceState) {
@@ -63,6 +64,7 @@ public abstract class BaseTvActivity extends PlaybackServiceActivity {
     @Override
     protected void onResume() {
         super.onResume();
+        mIsVisible = true;
         //Handle network connection state
         IntentFilter networkFilter = new IntentFilter(ConnectivityManager.CONNECTIVITY_ACTION);
 
@@ -81,6 +83,7 @@ public abstract class BaseTvActivity extends PlaybackServiceActivity {
 
     @Override
     protected void onPause() {
+        mIsVisible = false;
         super.onPause();
         unregisterReceiver(mExternalDevicesReceiver);
         LocalBroadcastManager.getInstance(this).unregisterReceiver(mParsingServiceReceiver);
@@ -114,6 +117,10 @@ public abstract class BaseTvActivity extends PlaybackServiceActivity {
         }
     };
 
+    protected boolean isVisible() {
+        return mIsVisible;
+    }
+
     protected void onParsingServiceStarted() {}
     protected void onParsingServiceFinished() {}
 
@@ -133,7 +140,8 @@ public abstract class BaseTvActivity extends PlaybackServiceActivity {
             } else if (action.equalsIgnoreCase(Intent.ACTION_MEDIA_MOUNTED)) {
                 String path = intent.getData().getPath();
                 String uuid = intent.getData().getLastPathSegment();
-                if (mMediaLibrary.addDevice(uuid, path, true)) {
+                boolean isIgnored = mSettings.getBoolean("ignore_"+ uuid, false);
+                if (!isIgnored && mMediaLibrary.addDevice(uuid, path, true, true)) {
                     startActivity(new Intent(BaseTvActivity.this, DialogActivity.class)
                             .setAction(DialogActivity.KEY_STORAGE)
                             .addFlags(Intent.FLAG_ACTIVITY_NEW_TASK)
