@@ -24,6 +24,7 @@
 package org.videolan.vlc.gui.tv.browser;
 
 import android.annotation.TargetApi;
+import android.app.Activity;
 import android.content.Intent;
 import android.os.Build;
 import android.os.Bundle;
@@ -38,10 +39,12 @@ import android.support.v17.leanback.widget.OnItemViewSelectedListener;
 import android.support.v17.leanback.widget.Presenter;
 import android.support.v17.leanback.widget.Row;
 import android.support.v17.leanback.widget.RowPresenter;
+import android.support.v4.content.ContextCompat;
 import android.support.v4.util.ArrayMap;
 import android.support.v4.util.SimpleArrayMap;
 
 import org.videolan.libvlc.Media;
+import org.videolan.medialibrary.media.MediaWrapper;
 import org.videolan.vlc.R;
 import org.videolan.vlc.VLCApplication;
 import org.videolan.vlc.gui.helpers.MediaComparators;
@@ -53,8 +56,6 @@ import org.videolan.vlc.gui.tv.TvUtil;
 import org.videolan.vlc.gui.tv.browser.interfaces.BrowserActivityInterface;
 import org.videolan.vlc.gui.tv.browser.interfaces.BrowserFragmentInterface;
 import org.videolan.vlc.gui.tv.browser.interfaces.DetailsFragment;
-import org.videolan.vlc.interfaces.IVideoBrowser;
-import org.videolan.vlc.media.MediaWrapper;
 import org.videolan.vlc.util.WeakHandler;
 
 import java.util.ArrayList;
@@ -63,12 +64,14 @@ import java.util.Map;
 import java.util.TreeMap;
 
 @TargetApi(Build.VERSION_CODES.JELLY_BEAN_MR1)
-public abstract class SortedBrowserFragment extends BrowseFragment implements BrowserFragmentInterface, OnItemViewSelectedListener, OnItemViewClickedListener, IVideoBrowser, DetailsFragment {
+public abstract class SortedBrowserFragment extends BrowseFragment implements BrowserFragmentInterface, OnItemViewSelectedListener, OnItemViewClickedListener, DetailsFragment {
 
     public static final String TAG = "VLC/SortedBrowserFragment";
 
     public static final String KEY_URI = "uri";
     public static final String SELECTED_ITEM = "selected";
+    public static final String CURRENT_BROWSER_LIST = "CURRENT_BROWSER_LIST";
+
     public static final int UPDATE_DISPLAY = 1;
     public static final int UPDATE_ITEM = 2;
     public static final int HIDE_LOADING = 3;
@@ -78,6 +81,7 @@ public abstract class SortedBrowserFragment extends BrowseFragment implements Br
     protected MediaWrapper mItemSelected;
     protected Map<String, ListItem> mMediaItemMap = new ArrayMap<>();
     SimpleArrayMap<String, Integer> mMediaIndex = new SimpleArrayMap<>();
+    ArrayList<MediaWrapper> mVideosList = new ArrayList<>();
     protected BrowserHandler mHandler = new BrowserHandler(this);
 
     abstract protected void browse();
@@ -85,16 +89,15 @@ public abstract class SortedBrowserFragment extends BrowseFragment implements Br
     @Override
     public void onCreate(Bundle savedInstanceState) {
         super.onCreate(savedInstanceState);
-        if (savedInstanceState != null){
+        if (savedInstanceState != null)
             mItemSelected = savedInstanceState.getParcelable(SELECTED_ITEM);
-        }
         setOnItemViewClickedListener(this);
         setOnItemViewSelectedListener(this);
         setAdapter(mAdapter);
 
         // UI setting
         setHeadersState(HEADERS_ENABLED);
-        setBrandColor(getResources().getColor(R.color.orange800));
+        setBrandColor(ContextCompat.getColor(getActivity(), R.color.orange800));
     }
 
     @Override
@@ -105,6 +108,11 @@ public abstract class SortedBrowserFragment extends BrowseFragment implements Br
             browse();
     }
 
+    @Override
+    public void onResume() {
+        super.onResume();
+        VLCApplication.storeData(CURRENT_BROWSER_LIST, mVideosList);
+    }
 
     @Override
     public void onSaveInstanceState(Bundle outState) {
@@ -163,19 +171,25 @@ public abstract class SortedBrowserFragment extends BrowseFragment implements Br
                 mMediaItemMap = new TreeMap<>(mMediaItemMap); //sort sections
                 for (ListItem item : mMediaItemMap.values()) {
                     Collections.sort(item.mediaList, MediaComparators.byFileType);
+                    mVideosList.addAll(item.mediaList);
                 }
                 mHandler.sendEmptyMessage(UPDATE_DISPLAY);
+                VLCApplication.storeData(CURRENT_BROWSER_LIST, mVideosList);
             }
         });
     }
 
     @Override
     public void updateList() {
-        mAdapter.clear();
+        Activity activity = getActivity();
+        if (activity == null)
+            return;
+        mAdapter = new ArrayObjectAdapter(new ListRowPresenter());
+        setAdapter(mAdapter);
         ArrayObjectAdapter adapter;
         HeaderItem header;
         for (ListItem item : mMediaItemMap.values()){
-            adapter = new ArrayObjectAdapter(new CardPresenter(getActivity()));
+            adapter = new ArrayObjectAdapter(new CardPresenter(activity));
             header = new HeaderItem(0, item.Letter);
             adapter.addAll(0, item.mediaList);
             mAdapter.add(new ListRow(header, adapter));
@@ -187,13 +201,17 @@ public abstract class SortedBrowserFragment extends BrowseFragment implements Br
         addMedia(new MediaWrapper(media));
     }
 
-    protected void addMedia(MediaWrapper mw){
+    protected void addMedia(MediaWrapper mw) {
         int type = mw.getType();
         if (type != MediaWrapper.TYPE_AUDIO && type != MediaWrapper.TYPE_VIDEO && type != MediaWrapper.TYPE_DIR)
             return;
         String letter = mw.getTitle().substring(0, 1).toUpperCase();
-        if (mMediaItemMap.containsKey(letter)){
-            mMediaItemMap.get(letter).mediaList.add(mw);
+        if (mMediaItemMap.containsKey(letter)) {
+            int position = mMediaItemMap.get(letter).mediaList.indexOf(mw);
+            if (position != -1) {
+                mMediaItemMap.get(letter).mediaList.set(position, mw);
+            } else
+                mMediaItemMap.get(letter).mediaList.add(mw);
         } else {
             ListItem item = new ListItem(letter, mw);
             mMediaItemMap.put(letter, item);
@@ -207,34 +225,17 @@ public abstract class SortedBrowserFragment extends BrowseFragment implements Br
         return mMediaItemMap.isEmpty();
     }
 
-    @Override
-    public void setItemToUpdate(MediaWrapper item) {
-        mHandler.obtainMessage(UPDATE_ITEM, item).sendToTarget();
-    }
-
     public void updateItem(MediaWrapper item) {
         if (mAdapter != null && mMediaIndex != null && item != null
                 && mMediaIndex.containsKey(item.getLocation()))
-            mAdapter.notifyArrayItemRangeChanged(mMediaIndex.get(item.getLocation()).intValue(), 1);
+            mAdapter.notifyArrayItemRangeChanged(mMediaIndex.get(item.getLocation()), 1);
     }
 
-    @Override
-    public void showProgressBar() {}
-
-    @Override
-    public void hideProgressBar() {}
-
-    @Override
-    public void clearTextInfo() {}
-
-    @Override
-    public void sendTextInfo(String info, int progress, int max) {}
-
     public static class ListItem {
-        public String Letter;
+        String Letter;
         public ArrayList<MediaWrapper> mediaList;
 
-        public ListItem(String letter, MediaWrapper mediaWrapper) {
+        ListItem(String letter, MediaWrapper mediaWrapper) {
             mediaList = new ArrayList<>();
             if (mediaWrapper != null)
                 mediaList.add(mediaWrapper);
@@ -243,7 +244,7 @@ public abstract class SortedBrowserFragment extends BrowseFragment implements Br
     }
 
     protected static class BrowserHandler extends WeakHandler<SortedBrowserFragment> {
-        public BrowserHandler(SortedBrowserFragment owner) {
+        BrowserHandler(SortedBrowserFragment owner) {
             super(owner);
         }
 
